@@ -22,7 +22,7 @@
 #endif
 
 #ifndef LIBFACTER_DEPRECATED
-#  define LIBFACTER_DEPRECATED 
+#  define LIBFACTER_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
 #ifndef LIBFACTER_DEPRECATED_EXPORT
@@ -39,4 +39,4 @@
 #  endif
 #endif
 
-#endif
+#endif /* LIBFACTER_EXPORT_H */
